Enum syntax::diagnostic::LevelUnstable
[-] [+]
[src]
pub enum Level {
Bug,
Fatal,
Error,
Warning,
Note,
Help,
}Variants
Bug | |
Fatal | |
Error | |
Warning | |
Note | |
Help |
pub enum Level {
Bug,
Fatal,
Error,
Warning,
Note,
Help,
}Bug | |
Fatal | |
Error | |
Warning | |
Note | |
Help |
impl Display for Levelimpl Debug for Levelimpl Clone for Levelfn clone(&self) -> Levelfn clone_from(&mut self, source: &Self)impl PartialEq for Levelimpl Copy for Level
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).